#!/bin/sh
# Slackware Installation Script for SpamAssassin
# Peter Hyman

# new screening method for perllocal.pod file
# if it exists, filter out references to SpamAssassin
# then, concatenate new .pod addition file to end.

PERLDIR=/usr/lib/perl5/5.8.6/i486-linux
PODFILE=perllocal.pod
FULLPATH=$PERLDIR/$PODFILE
TMPFILE=$FULLPATH.new
SAFILE=$FULLPATH.sa
ETCPATH=/etc/mail/spamassassin
RCPATH=/etc/rc.d

# IF there is an existing perllocal.pod file, then
# parse it to remove existing SpamAssassin references, if any.
# if NOT, then just concatenate the perllocal.pod.sa file
# to an existing perllocal.pod file or create a new one.

if [ -r $FULLPATH ] ; then
   # now sed it to get rid of SA references
   if  grep Mail::SpamAssassin $FULLPATH >/dev/null ; then
      (cat $FULLPATH | sed -n '
      :x
      /Mail::SpamAssassin/! { p; b }
      :y
      /^=back/! { n; by }') >$TMPFILE
      mv $TMPFILE $FULLPATH
   fi
fi

# now concatenate new pod info
# if no file, then new one created.

cat $SAFILE >> $FULLPATH 

# remove temporary file.
rm $SAFILE

# see if spamassassin config files already installed, if so, leave .new ones
# if not, move .new ones over

if [ ! -r $ETCPATH/init.pre ]; then
	mv $ETCPATH/init.pre.new $ETCPATH/init.pre
else
	echo "Check differences between $ETCPATH/init.pre.new file and existing one"
fi

if [ ! -r $ETCPATH/local.cf ]; then
	mv $ETCPATH/local.cf.new $ETCPATH/local.cf
else
	echo "Check differences between $ETCPATH/local.cf.new file and existing one"
fi

if [ ! -r $RCPATH/rc.spamassassin ]; then
	mv $RCPATH/rc.spamassassin.new $RCPATH/rc.spamassassin
else
	echo "Check differences between $RCPATH/rc.spamassassin.new file and existing one"
fi

echo -e "\n"
echo "SpamAssassin 3.0.2 has been installed. The startup script, rc.spamassassin"
echo "has been installed in $RCPATH. It is NOT marked executable."
echo "To automatically have SpamAssassin start each boot, chomod +x to the file"
echo "and add \"rc.spamassassin start\" to your $RCPATH/rc.local file."
echo "More information is available at http://www.spamassassin.org and the"
echo "man pages."
echo -e "\n"
